@@ -37,16 +37,15 @@ class CreateKnowledgeBase(ASTNode):
 
     def to_tree(self, *args, level=0, **kwargs):
         ind = indent(level)
-        storage_str = f"{ind} storage={self.storage.to_string()},\n" if self.storage else ""
-        model_str = f"{ind} model={self.model.to_string()},\n" if self.model else ""
-        out_str = f"""
-        {ind}CreateKnowledgeBase(
-        {ind}    if_not_exists={self.if_not_exists},
-        {ind}    name={self.name.to_string()},
-        {ind}    from_query={self.from_query.to_tree(level=level + 1) if self.from_query else None},
-        {model_str}{storage_str}{ind}    params={self.params}
-        {ind})
-        """
+        storage_str = f"{ind}  storage={self.storage.to_string()},\n" if self.storage else ""
+        model_str = f"{ind}  model={self.model.to_string()},\n" if self.model else ""
+        out_str = f"{ind}CreateKnowledgeBase(\n" \
+        f"{ind}  if_not_exists={self.if_not_exists},\n" \
+        f"{ind}  name={self.name.to_string()},\n" \
+        f"{ind}  from_query={self.from_query.to_tree(level=level + 1) if self.from_query else None},\n" \
+        f"{ind}{model_str}{storage_str}{ind}  params={self.params}\n" \
+        f"{ind})"
+
         return out_str
 
     def get_string(self, *args, **kwargs):
@@ -80,6 +79,55 @@ class CreateKnowledgeBase(ASTNode):
         return self.to_tree()
 
 
+class AlterKnowledgeBase(ASTNode):
+    """
+    Update the knowledge base
+    """
+    def __init__(
+        self,
+        name,
+        params=None,
+        *args,
+        **kwargs,
+    ):
+        """
+        Args:
+            name: Identifier -- name of the knowledge base
+            params: dict -- additional parameters to pass to the knowledge base. E.g., chunking strategy, etc.
+        """
+        super().__init__(*args, **kwargs)
+        self.name = name
+        self.params = params
+    def to_tree(self, *args, level=0, **kwargs):
+        ind = indent(level)
+        out_str = f"{ind}AlterKnowledgeBase(\n" \
+        f"{ind}  name={self.name.to_string()},\n" \
+        f"{ind}  params={self.params}\n" \
+        f"{ind})"
+        return out_str
+
+    def get_string(self, *args, **kwargs):
+
+        using_ar = []
+        params = self.params.copy()
+        if params:
+            using_ar += [f"{k}={repr(v)}" for k, v in params.items()]
+        if using_ar:
+            using_str = "USING " + ", ".join(using_ar)
+        else:
+            using_str = ""
+
+        out_str = (
+            f"ALTER KNOWLEDGE_BASE {self.name.to_string()} "
+            f"{using_str}"
+        )
+
+        return out_str
+
+    def __repr__(self) -> str:
+        return self.to_tree()
+
+
 class DropKnowledgeBase(ASTNode):
     """
     Delete a knowledge base
